@@ -111,7 +111,7 @@ def query_xc (species_list,
 def download_xc (df_dataset,
                 rootdir, 
                 dataset_name, 
-                csv_filename="bam_metadata.csv",
+                csv_filename="bambird_metadata.csv",
                 overwrite=False,
                 verbose=True):
     """
@@ -131,7 +131,7 @@ def download_xc (df_dataset,
     csv_filename : string, optional
         Name of the csv file where the dataframe (df_dataset) will be saved. if
         the file already exists, data will be appended at the end of the csv file.
-        The default is bam_metadata.csv
+        The default is bambird_metadata.csv
     overwrite : boolean, optional
         Test if the directory where the audio files will be downloaded already
         exists. if True, it will download the data in the directory anyway.
@@ -217,6 +217,114 @@ def download_xc (df_dataset,
                         
     return df_dataset, csv_fullfilename
 
+#%%
+
+def query_download_xc(
+        species_list, 
+        rootdir, 
+        dataset_name, 
+        params=cfg.PARAMS['PARAMS_XC'],
+        csv_filename="bambird_metadata.csv",
+        increment=True,
+        format_time=False,
+        format_date=False,
+        random_seed=cfg.RANDOM_SEED,  
+        overwrite=False,
+        verbose=False
+        ):
+    """
+    
+
+    Parameters
+    ----------
+    species_list : TYPE
+        DESCRIPTION.
+    rootdir : TYPE
+        DESCRIPTION.
+    dataset_name : TYPE
+        DESCRIPTION.
+    params : TYPE, optional
+        DESCRIPTION. The default is cfg.PARAMS['PARAMS_XC'].
+    csv_filename : TYPE, optional
+        DESCRIPTION. The default is "bambird_metadata.csv".
+    format_time : TYPE, optional
+        DESCRIPTION. The default is False.
+    format_date : TYPE, optional
+        DESCRIPTION. The default is False.
+    random_seed : TYPE, optional
+        DESCRIPTION. The default is cfg.RANDOM_SEED.
+    overwrite : TYPE, optional
+        DESCRIPTION. The default is False.
+    verbose : TYPE, optional
+        DESCRIPTION. The default is False.
+
+    Returns
+    -------
+    None.
+
+    """
+    
+    # Set the full path to the dataset containing all the metadata downloaded
+    # from XC and then, the filename and fullfilename of the recordings downloaded
+    # with the function download_xc
+    csv_fullfilename = Path(rootdir) / Path(dataset_name) / csv_filename
+    
+    # number of file to download
+    NUM_FILES = params['PARAMS_XC']['NUM_FILES']
+
+    if os.path.isfile(csv_fullfilename) == False :
+        params['PARAMS_XC']['NUM_FILES'] = None
+        df_dataset = query_xc (species_list  =species_list, 
+                                params       =params,
+                                format_time  =format_time,
+                                format_date  =format_date,
+                                random_seed  =random_seed, 
+                                verbose      =False)
+    else:
+        df_dataset = pd.read_csv(csv_fullfilename, sep=';', index = False)
+        
+        if verbose:
+            print((("The metadata file {} already exits\n") +
+                  ("with {} audio recordings")).format(csv_fullfilename,
+                                                      len(df_dataset)))
+    
+        # Test if we ask for new files to be downloaded (increment == True)
+        if increment :
+            # Keep only the xc recordings that have not been yet downloaded
+            df_dataset = df_dataset[df_dataset['fullfilename']==None]
+            
+            # if no limit in the number of files
+            if NUM_FILES is not None :
+                # test if the number of files is greater than the maximum number of
+                # resquested files
+                if len(df_dataset) > NUM_FILES : 
+                    df_dataset = df_dataset.sample(n = NUM_FILES,
+                                                   random_state = random_seed)
+            
+            df, csv = download_xc (df_dataset      =df_dataset,
+                                        rootdir         =rootdir, 
+                                        dataset_name    =dataset_name, 
+                                        csv_filename    =csv_filename,
+                                        overwrite       =overwrite,
+                                        verbose         =verbose) 
+        
+        # if we                 
+        else:
+            # Keep the xc recordings that have already been downloaded
+            df_dataset = df_dataset[df_dataset['fullfilename']!=None]
+            
+            # if no limit in the number of files
+            if NUM_FILES is not None :
+                # test if the number of files is greater than the maximum number of
+                # resquested files
+                if len(df_dataset) > NUM_FILES : 
+                    df = df_dataset.sample(n = NUM_FILES,
+                                           random_state = random_seed)
+                
+                
+
+    return df, csv
+
 #%%
 def grab_audio_to_df (path, 
                       audio_format, 
